{
    ZLib Header for Delphi 3.01
}

unit ZLib;

interface

const
  ZLIB_VERSION = '1.1.4';

type
  voidpf = Pointer;
  int    = Integer;
  uInt   = Integer;//Cardinal;
  pBytef = PChar;
  uLong  = Integer;//Cardinal;

  alloc_func = function(opaque: voidpf; items, size: uInt): voidpf;
  free_func  = procedure(opaque, address: voidpf);

  internal_state = Pointer;

  z_streamp = ^z_stream;
  z_stream = packed record
    next_in: pBytef;          // next input byte
    avail_in: uInt;           // number of bytes available at next_in
    total_in: uLong;          // total nb of input bytes read so far

    next_out: pBytef;         // next output byte should be put there
    avail_out: uInt;          // remaining free space at next_out
    total_out: uLong;         // total nb of bytes output so far

    msg: PChar;               // last error message, NULL if no error
    state: internal_state;    // not visible by applications

    zalloc: alloc_func;       // used to allocate the internal state
    zfree: free_func;         // used to free the internal state
    opaque: voidpf;           // private data object passed to zalloc and zfree

    data_type: int;           // best guess about the data type: ascii or binary
    adler: uLong;             // adler32 value of the uncompressed data
    reserved: uLong;          // reserved for future use
  end;

const
  Z_NO_FLUSH      = 0;
  Z_PARTIAL_FLUSH = 1; // will be removed, use Z_SYNC_FLUSH instead
  Z_SYNC_FLUSH    = 2;
  Z_FULL_FLUSH    = 3;
  Z_FINISH        = 4;

  Z_OK            = 0;
  Z_STREAM_END    = 1;
  Z_NEED_DICT     = 2;
  Z_ERRNO         = -1;
  Z_STREAM_ERROR  = -2;
  Z_DATA_ERROR    = -3;
  Z_MEM_ERROR     = -4;
  Z_BUF_ERROR     = -5;
  Z_VERSION_ERROR = -6;

  Z_NO_COMPRESSION      =  0;
  Z_BEST_SPEED          =  1;
  Z_BEST_COMPRESSION    =  9;
  Z_DEFAULT_COMPRESSION = -1;

  Z_FILTERED         = 1;
  Z_HUFFMAN_ONLY     = 2;
  Z_DEFAULT_STRATEGY = 0;

  Z_BINARY  = 0;
  Z_ASCII   = 1;
  Z_UNKNOWN = 2;

  Z_DEFLATED = 8;

  Z_NULL = 0;

function adler32(adler: uLong; const buf: pBytef; len: uInt): uLong; stdcall; external;
//function crc32(crc: uLong; const buf: pBytef; len: uInt): uLong; external;
function deflate(strm: z_streamp; flush: int): int; stdcall; external;
function deflateCopy(dest, source: z_streamp): int; stdcall; external;
function deflateEnd(strm: z_streamp): int; stdcall; external;
function deflateInit2_(strm: z_streamp; level, method, windowBits, memLevel, strategy: int;
  const version: PChar; stream_size: int): int; stdcall; external;
function deflateInit_(strm: z_streamp; level: int;
  const version: PChar; stream_size: int): int; stdcall; external;
function deflateParams(strm: z_streamp; level, strategy: int): int; stdcall; external;
function deflateReset(strm: z_streamp): int; stdcall; external;
function deflateSetDictionary(strm: z_streamp; const dictionary: pBytef;
  dictLength: uInt): int; stdcall; external;
function inflate(strm: z_streamp; flush: int): int; stdcall; external;
function inflateEnd(strm: z_streamp): int; stdcall; external;
function inflateInit2_(strm: z_streamp; windowBits: int;
  const version: PChar; stream_size: int): int; stdcall; external;
function inflateInit_(strm: z_streamp; const version: PChar;
  stream_size: int): int; stdcall; external;
function inflateReset(strm: z_streamp): int; stdcall; external;
function inflateSetDictionary(strm: z_streamp; const dictionary: pBytef;
  dictLength: uInt): int; stdcall; external;
function inflateSync(strm: z_streamp): int; stdcall; external;

function deflateInit(strm: z_streamp; level: int): int;
function deflateInit2(strm: z_streamp; level, method, windowBits, memLevel, strategy: int): int;
function inflateInit(strm: z_streamp): int;
function inflateInit2(strm: z_streamp; windowBits: int): int;

const
  { from zconf.h }

  // Maximum value for memLevel in deflateInit2
  MAX_MEM_LEVEL = 9;

  MAX_WBITS = 15; // 32K LZ77 window

  { from zutil.c }

  _z_errmsg: array[0..9] of PChar = (
    'need dictionary',      // Z_NEED_DICT      (2)
    'stream end',           // Z_STREAM_END     (1)
    '',                     // Z_OK             (0)
    'file error',           // Z_ERRNO          (-1)
    'stream error',         // Z_STREAM_ERROR   (-2)
    'data error',           // Z_DATA_ERROR     (-3)
    'insufficient memory',  // Z_MEM_ERROR      (-4)
    'buffer error',         // Z_BUF_ERROR      (-5)
    'incompatible version', // Z_VERSION_ERROR  (-6)
    ''
  );

implementation

{$L deflate.obj}
{$L inflate.obj}
{$L infblock.obj}
{$L inftrees.obj}
{$L infcodes.obj}
{$L infutil.obj}
{$L inffast.obj}
{$L trees.obj}
{$L adler32.obj}
// note: do not reorder the above -- doing so will result in external
// functions being undefined

function deflateInit(strm: z_streamp; level: int): int;
begin
  Result := deflateInit_(strm, level, ZLIB_VERSION, sizeof(z_stream));
end;

function deflateInit2(strm: z_streamp; level, method, windowBits, memLevel, strategy: int): int;
begin
  Result := deflateInit2_(strm, level, method, windowBits, memLevel,
    strategy, ZLIB_VERSION, sizeof(z_stream));
end;

function inflateInit(strm: z_streamp): int;
begin
  Result := inflateInit_(strm, ZLIB_VERSION, sizeof(z_stream));
end;

function inflateInit2(strm: z_streamp; windowBits: int): int;
begin
  Result := inflateInit2_(strm, windowBits, ZLIB_VERSION, sizeof(z_stream));
end;

// zlib function

function zcalloc(opaque: voidpf; items, size: uInt): voidpf; stdcall;
begin
  GetMem(result, items * size);
end;

procedure zcfree(opaque, address: voidpf); stdcall;
begin
  FreeMem(address);
end;

// C function

procedure _memset(p: Pointer; b: Byte; count: Integer); cdecl;
begin
  FillChar(p^, count, b);
end;

procedure _memcpy(dest, source: Pointer; count: Integer); cdecl;
begin
  Move(source^, dest^, count);
end;

end.
