unit unzip;

interface

uses ZLib;

const
{
  ZIP_FILE_HEADER_SIGN = $04034b50;
  ZIP_EXTENDED_HEADER_SIGN = $08074b50;
  ZIP_CENTRALDIR_HEADER_SIGN = $02014b50;
  ZIP_END_CENTRALDIR_HEADER_SIGN = $06054b50;
}
  ZIP_FILE_HEADER_SIGN = 'PK'#03#04;
  ZIP_EXTENDED_HEADER_SIGN = 'PK'#07#08;
  ZIP_CENTRALDIR_HEADER_SIGN = 'PK'#01#02;
  ZIP_END_CENTRALDIR_HEADER_SIGN = 'PK'#05#06;

type
  PZipFileHeader = ^TZipFileHeader;
  TZipFileHeader = packed record
    VersionNeeded: Word;
    Flag: Word;
    Method: Word;
    FileMTime: Word;
    FileMDate: Word;
    Crc: Longint;
    CompSize: Longint;
    UnCompSize: Longint;
    FileNameLen: Word;
    ExtraFieldLen: Word;
  end;

  TZipExtendedHeader = packed record
    Crc: Longint;
    CompSize: Longint;
    UnCompSize: Longint;
  end;

  TCentralDirectory = packed record
    VersionMadeBy: Word;
    VersionNeeded: Word;
    Flag: Word;
    Method: Word;
    FileMTime: Word;
    FileMDate: Word;
    Crc: Longint;
    CompSize: Longint;
    UnCompSize: Longint;
    FileNameLen: Word;
    ExtraFieldLen: Word;
    FileCommentLen: Word;
    DiskNumberStart: Word;
    InternalFileAttr: Word;
    ExternalFileAttr: Longint;
    LocalHeaderOffset: Longint;
  end;

  TEndOfCentralDirectory = packed record
    NumThisDisk: Word;
    NumDiskStartDir: Word;
    NumEntriesCentralDirThisDisk: Word;
    TotalEntriesCentralDir: Word;
    SizeCentralDir: Longint;
    OffsetStartCentralDir: Longint;
    ZipFileCommentLen: Word;
  end;

function Decompress(const InBuf: string; var OutBuf: string; OutSize: Integer): Integer;

implementation

function Decompress(const InBuf: string; var OutBuf: string; OutSize: Integer): Integer;
var
  zs: z_stream;
begin
  FillChar(zs, SizeOf(z_stream), 0);
  SetLength(OutBuf, OutSize);
  zs.next_in := PChar(InBuf);
  zs.avail_in := Length(InBuf);
  zs.next_out := PChar(OutBuf);
  zs.avail_out := OutSize;
  Result := inflateInit2(@zs, -MAX_WBITS);
  if Result < Z_OK then
    Exit;
  try
    Result := inflate(@zs, Z_NO_FLUSH);
  finally
    inflateEnd(@zs);
  end;
end;

end.
 